==> inti-moto-cli-1.0.0-01683b.tar: src/Import/Data.php <==
<?php
declare(strict_types=1);

namespace Inti\Moto\Console\Import;

use Doctrine\DBAL\Connection;
use Doctrine\DBAL\Driver\Exception;
use Doctrine\DBAL\Exception as DbalException;
use PhpOffice\PhpSpreadsheet\Cell\Cell;
use PhpOffice\PhpSpreadsheet\IOFactory;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Throwable;
use function array_map;
use function array_values;
use function floatval;
use function intval;
use function iterator_to_array;
use function preg_quote;
use function preg_replace;

/**
 * Class Import
 *
 * @package Inti\Moto\Console\Import
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-moto-cli
 */
final class Data extends Command
{
    const IMAGE = 2;
    const MAKE = 3;
    const MODEL = 4;
    const YEAR = 5;
    const CATEGORY = 6;
    const ENGINE_DISPLACEMENT = 9;
    const ENGINE_TYPE = 10;
    const ENGINE = 11;
    const POWER_PS = 12;
    const POWER_RPM = 13;
    const TORQUE_NM = 14;
    const TORQUE_RPM = 15;
    const VALVES_PER_CYLINDER = 23;
    const FUEL_SYSTEM = 24;
    const FUEL_CONTROL = 25;
    const INGITION = 26;
    const LUBRICATION_SYSTEM = 27;
    const COOLING_SYSTEM = 28;
    const GEARBOX = 29;
    const TRANSMISSION_TYPE = 30;
    const CLUTCH = 31;
    const EXHAUST_SYSTEM = 36;
    const FRONT_SUSPENSION = 40;
    const REAR_SUSPENSION = 42;
    const FRONT_TIRE = 44;
    const REAR_TIRE = 45;
    const FRONT_BRAKES = 46;
    const FRONT_BRAKES_DIAMETER = 47;
    const REAR_BRAKES = 48;
    const REAR_BRAKES_DIAMETER = 49;
    const DRY_WEIGHT = 52;
    const FULL_WEIGHT = 53;
    const SEAT_HEIGHT = 55;
    const FRONT_WEIGHT = 57;
    const REAR_WEIGHT = 58;
    const HEIGHT = 59;
    const LENGTH = 60;
    const WIDTH = 61;
    const GROUND_CLEARANCE = 62;
    const WHEELBASE = 63;
    const FUEL_CAPACITY = 64;
    const RESERVE_FUEL_CAPACITY = 65;
    const OIL_CAPACITY = 66;
    const STARTER = 68;
    const ELECTRICAL = 70;

    private Connection $conn;

    /** @var array<int, array<string, int>> */
    private array $models = [];
    /** @var array<string, int> */
    private array $names = [];

    public function __construct(Connection $conn)
    {
        parent::__construct('import:data');
        $this->conn = $conn;
    }

    protected function configure(): void
    {
        $this->setDescription('Uvozi podatke o motociklima iz Teoalida Excel datoteke.')
            ->addArgument('datoteka', InputArgument::REQUIRED, 'Putanja do datoteke.');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $file = realpath($input->getArgument('datoteka'));

        try {
            $spreadsheet = IOFactory::load($file);

            $sheet = $spreadsheet->getActiveSheet();
            $rows = $sheet->getRowIterator(19000);

            foreach ($rows as $row) {
               $this->import(array_values(array_map(function (Cell $cell) {
                    return $cell->getValue();
                }, iterator_to_array($row->getCellIterator()))));
            }

            return Command::SUCCESS;
        } catch (Throwable $e) {
            $output->writeln([
                'Došlo je do neakve pogreške:',
                '============================',
                $e->getMessage(),
            ]);

            return Command::SUCCESS;
        }
    }

    /**
     * @param array $row
     * @throws DbalException
     * @throws Exception
     */
    private function import(array $row): void
    {
        if (empty($row[1])) return;

        $row = array_map('trim', $row);

        $make = $row[self::MAKE];
        $makeId = $this->make($make);

        $model = preg_replace('/^' . preg_quote($make, '/') . ' /', '', $row[self::MODEL]);
        $modelId = $this->model($makeId, $model);

        $year = intval($row[self::YEAR]);

        $existing = $this->conn->executeQuery(
            'SELECT id FROM bike WHERE make_id = ? AND model_id = ? AND year = ?',
            [$makeId, $modelId, $year]
        );

        if ($existing->rowCount() > 0) {
            return;
        }

        $this->conn->insert('bike', [
            'make_id' => $makeId,
            'model_id' => $modelId,
            'category_id' => $this->name('category', $row[self::CATEGORY]),
            'image_id' => $this->image($row[self::IMAGE]),
            'engine_type_id' => $this->name('engine_type', $row[self::ENGINE_TYPE]),
            'engine_id' => $this->name('engine', $row[self::ENGINE]),
            'fuel_system_id' => $this->name('fuel_system', $row[self::FUEL_SYSTEM]),
            'fuel_control_id' => $this->name('fuel_control', $row[self::FUEL_CONTROL]),
            'ignition_id' => $this->name('ignition', $row[self::INGITION]),
            'lubrication_system_id' => $this->name('lubrication_system', $row[self::LUBRICATION_SYSTEM]),
            'cooling_system_id' => $this->name('cooling_system', $row[self::COOLING_SYSTEM]),
            'gearbox_id' => $this->name('gearbox', $row[self::GEARBOX]),
            'transmission_type_id' => $this->name('transmission_type', $row[self::TRANSMISSION_TYPE]),
            'clutch_id' => $this->name('clutch', $row[self::CLUTCH]),
            'exhaust_system_id' => $this->name('exhaust_system', $row[self::EXHAUST_SYSTEM]),
            'front_suspension_id' => $this->name('suspension', $row[self::FRONT_SUSPENSION]),
            'rear_suspension_id' => $this->name('suspension', $row[self::REAR_SUSPENSION]),
            'front_brakes_id' => $this->name('brake', $row[self::FRONT_BRAKES]),
            'rear_brakes_id' => $this->name('brake', $row[self::REAR_BRAKES]),
            'starter_id' => $this->name('starter', $row[self::STARTER]),
            'electrical_id' => $this->name('electrical', $row[self::ELECTRICAL]),
            'year' => $year,
            'slug' => $this->slug($make, $model, $year),
            'engine_displacement' => $this->float($row[self::ENGINE_DISPLACEMENT]),
            'power_ps' => $this->float($row[self::POWER_PS]),
            'power_rpm' => $this->int($row[self::POWER_RPM]),
            'torque_nm' => $this->float($row[self::TORQUE_NM]),
            'torque_rpm' => $this->int($row[self::TORQUE_RPM]),
            'valves_per_cylinder' => $this->int($row[self::VALVES_PER_CYLINDER]),
            'front_tire' => $row[self::FRONT_TIRE] ?: null,
            'rear_tire' => $row[self::REAR_TIRE] ?: null,
            'front_brakes_diameter' => $this->int($row[self::FRONT_BRAKES_DIAMETER]),
            'rear_brakes_diameter' => $this->int($row[self::REAR_BRAKES_DIAMETER]),
            'dry_weight' => $this->float($row[self::DRY_WEIGHT]),
            'full_weight' => $this->float($row[self::FULL_WEIGHT]),
            'seat_height' => $this->int($row[self::SEAT_HEIGHT]),
            'front_weight' => $this->float($row[self::FRONT_WEIGHT]),
            'rear_weight' => $this->float($row[self::REAR_WEIGHT]),
            'height' => $this->int($row[self::HEIGHT]),
            'length' => $this->int($row[self::LENGTH]),
            'width' => $this->int($row[self::WIDTH]),
            'ground_clearance' => $this->int($row[self::GROUND_CLEARANCE]),
            'wheelbase' => $this->int($row[self::WHEELBASE]),
            'fuel_capacity' => $this->float($row[self::FUEL_CAPACITY]),
            'reserve_fuel_capacity' => $this->float($row[self::RESERVE_FUEL_CAPACITY]),
            'oil_capacity' => $this->float($row[self::OIL_CAPACITY]),
        ]);
    }

    /**
     * @param string $make
     * @param string $model
     * @param int $year
     * @return string
     * @throws DbalException
     * @throws Exception
     */
    private function slug(string $make, string $model, int $year): string
    {
        $slug = preg_replace('/\s+/', '-', $make . ' ' . $model . ' ' . $year);
        $slug = $baseSlug = strtolower($slug);

        $i = 1;
        $query = $this->conn->prepare('SELECT 1 FROM bike WHERE slug = ?');
        $existing = $query->execute([$slug]);

        while ($existing->rowCount() > 0) {
            $slug = $baseSlug . '-' . ($i++);
            $existing = $query->execute([$slug]);
        }

        return $slug;
    }

    /**
     * @param string|int|float|null $value
     * @return float|null
     */
    private function float($value): ?float
    {
        return !empty($value) ? floatval($value) : null;
    }

    /**
     * @param string|int|null $value
     * @return int|null
     */
    private function int($value): ?int
    {
        return !empty($value) ? intval($value) : null;
    }

    /**
     * @param string $table
     * @param string|null $name
     * @return int
     * @throws DbalException
     */
    private function name(string $table, ?string $name): ?int
    {
        if ($name === null || empty($name)) {
            return null;
        }

        $key = strtolower($name);

        if (!isset($this->names[$table][$key])) {
            $existing = $this->conn->executeQuery('SELECT id, name_en FROM ' . $table . ' WHERE name_en  = ?', [$name]);

            if ($existing->rowCount() === 1) {
                $row = $existing->fetchAssociative();
                $this->names[$table][$key] = intval($row['id']);
            } else {
                $this->conn->insert($table, [
                    'name_en' => $name,
                ]);
                $this->names[$table][$key] = intval($this->conn->lastInsertId());
            }
        }

        return $this->names[$table][$key];
    }

    /**
     * @param string $name
     * @return int
     * @throws DbalException
     */
    private function make(string $name): int
    {
        if (!isset($this->names['make'][$name])) {
            $existing = $this->conn->executeQuery(
                'SELECT * FROM make WHERE name = ?',
                [$name]
            );

            if ($existing->rowCount() > 0) {
                $row  = $existing->fetchAssociative();
                $this->names['make'][$name] = intval($row['id']);
            } else {
                $this->conn->insert('make', [
                    'name' => $name,
                ]);
                $this->names['make'][$name] = intval($this->conn->lastInsertId());
            }
        }

        return $this->names['make'][$name];
    }

    /**
     * @param int $makeId
     * @param string $name
     * @return int
     * @throws DbalException
     */
    private function model(int $makeId, string $name): int
    {
        if (!isset($this->models[$makeId][$name])) {
            $existing = $this->conn->executeQuery(
                'SELECT * FROM model WHERE make_id = ? AND name = ?',
                [$makeId, $name]
            );

            if ($existing->rowCount() > 0) {
                $row  = $existing->fetchAssociative();
                $this->models[intval($row['make_id'])][$name] = intval($row['id']);
            } else {
                $this->conn->insert('model', [
                    'make_id' => $makeId,
                    'name' => $name,
                ]);
                $this->models[$makeId][$name] = intval($this->conn->lastInsertId());
            }
        }

        return $this->models[$makeId][$name];
    }

    /**
     * @param string|null $url
     * @return int|null
     * @throws DbalException
     */
    private function image(?string $url): ?int
    {
        if (empty($url)) {
            return null;
        }

        if (!isset($this->names['image'][$url])) {
            $existing = $this->conn->executeQuery('SELECT * FROM image WHERE url = ?', [$url]);

            if ($existing->rowCount() > 0) {
                $row = $existing->fetchAssociative();
                $this->names['image'][$url] = intval($row['id']);
            } else {
                $this->conn->insert('image', ['url' => $url]);
                $this->names['image'][$url] = intval($this->conn->lastInsertId());
            }
        }

        return $this->names['image'][$url];
    }
}

==> inti-moto-cli-1.1.0-406284.tar: src/Import/Data.php <==
<?php
declare(strict_types=1);

namespace Inti\Moto\Console\Import;

use Doctrine\DBAL\Connection;
use Doctrine\DBAL\Driver\Exception;
use Doctrine\DBAL\Exception as DbalException;
use PhpOffice\PhpSpreadsheet\Cell\Cell;
use PhpOffice\PhpSpreadsheet\IOFactory;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Helper\ProgressBar;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;
use Throwable;
use function array_map;
use function array_values;
use function floatval;
use function intval;
use function iterator_to_array;
use function preg_quote;
use function preg_replace;

/**
 * Class Import
 *
 * @package Inti\Moto\Console\Import
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-moto-cli
 */
final class Data extends Command
{
    const IMAGE = 2;
    const MAKE = 3;
    const MODEL = 4;
    const YEAR = 5;
    const CATEGORY = 6;
    const ENGINE_DISPLACEMENT = 9;
    const ENGINE_TYPE = 10;
    const ENGINE = 11;
    const POWER_PS = 12;
    const POWER_RPM = 13;
    const TORQUE_NM = 14;
    const TORQUE_RPM = 15;
    const VALVES_PER_CYLINDER = 23;
    const FUEL_SYSTEM = 24;
    const FUEL_CONTROL = 25;
    const INGITION = 26;
    const LUBRICATION_SYSTEM = 27;
    const COOLING_SYSTEM = 28;
    const GEARBOX = 29;
    const TRANSMISSION_TYPE = 30;
    const CLUTCH = 31;
    const EXHAUST_SYSTEM = 36;
    const FRONT_SUSPENSION = 40;
    const REAR_SUSPENSION = 42;
    const FRONT_TIRE = 44;
    const REAR_TIRE = 45;
    const FRONT_BRAKES = 46;
    const FRONT_BRAKES_DIAMETER = 47;
    const REAR_BRAKES = 48;
    const REAR_BRAKES_DIAMETER = 49;
    const DRY_WEIGHT = 52;
    const FULL_WEIGHT = 53;
    const SEAT_HEIGHT = 55;
    const FRONT_WEIGHT = 57;
    const REAR_WEIGHT = 58;
    const HEIGHT = 59;
    const LENGTH = 60;
    const WIDTH = 61;
    const GROUND_CLEARANCE = 62;
    const WHEELBASE = 63;
    const FUEL_CAPACITY = 64;
    const RESERVE_FUEL_CAPACITY = 65;
    const OIL_CAPACITY = 66;
    const STARTER = 68;
    const ELECTRICAL = 70;

    private Connection $conn;

    /** @var array<int, array<string, int>> */
    private array $models = [];
    /** @var array<string, int> */
    private array $slugs = [];

    public function __construct(Connection $conn)
    {
        parent::__construct('import:data');
        $this->conn = $conn;
    }

    protected function configure(): void
    {
        $this->setDescription('Uvozi podatke o motociklima iz Teoalida Excel datoteke.')
            ->addArgument('datoteka', InputArgument::REQUIRED, 'Putanja do datoteke.')
            ->addOption('offset', 'o', InputOption::VALUE_OPTIONAL);
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $file = realpath($input->getArgument('datoteka'));
        $offset = intval($input->getOption('offset'));

        try {
            $output->writeln('<info>Loading the excel file...</info>');
            $spreadsheet = IOFactory::load($file);

            $sheet = $spreadsheet->getActiveSheet();
            $rows = $sheet->getRowIterator($offset);

            $progressBar = new ProgressBar($output);
            $output->writeln('Importing the data...');

            foreach ($progressBar->iterate($rows, $sheet->getHighestDataRow() - $offset) as $i => $row) {
                $row = array_values(array_map(function (Cell $cell) {
                    return $cell->getValue();
                }, iterator_to_array($row->getCellIterator())));

                $this->import($row);
            }

            $output->writeln(['', '<info>Done!</info>']);

            return Command::SUCCESS;
        } catch (Throwable $e) {
            $output->writeln([
                'Došlo je do neakve pogreške:',
                print_r($row ?? [], true),
                '============================',
                $e->getMessage(),
            ]);

            return Command::SUCCESS;
        }
    }

    /**
     * @param array $row
     * @throws DbalException
     * @throws Exception
     */
    private function import(array $row): void
    {
        if (empty($row[1])) return;

        $row = array_map('trim', $row);

        $make = $row[self::MAKE];
        $makeId = $this->make($make);

        $model = preg_replace('/^' . preg_quote($make, '/') . ' /', '', $row[self::MODEL]);
        $modelId = $this->model($makeId, $model);

        $year = intval($row[self::YEAR]);

        $existing = $this->conn->executeQuery(
            'SELECT id FROM bike WHERE make_id = ? AND model_id = ? AND year = ?',
            [$makeId, $modelId, $year]
        );

        if ($existing->rowCount() > 0) {
            return;
        }

        $this->conn->insert('bike', [
            'make_id' => $makeId,
            'model_id' => $modelId,
            'category_id' => $this->name('category', $row[self::CATEGORY]),
            'image_id' => $this->image($row[self::IMAGE]),
            'engine_type_id' => $this->name('engine_type', $row[self::ENGINE_TYPE]),
            'engine_id' => $this->name('engine', $row[self::ENGINE]),
            'fuel_system_id' => $this->name('fuel_system', $row[self::FUEL_SYSTEM]),
            'fuel_control_id' => $this->name('fuel_control', $row[self::FUEL_CONTROL]),
            'ignition_id' => $this->name('ignition', $row[self::INGITION]),
            'lubrication_system_id' => $this->name('lubrication_system', $row[self::LUBRICATION_SYSTEM]),
            'cooling_system_id' => $this->name('cooling_system', $row[self::COOLING_SYSTEM]),
            'gearbox_id' => $this->name('gearbox', $row[self::GEARBOX]),
            'transmission_type_id' => $this->name('transmission_type', $row[self::TRANSMISSION_TYPE]),
            'clutch_id' => $this->name('clutch', $row[self::CLUTCH]),
            'exhaust_system_id' => $this->name('exhaust_system', $row[self::EXHAUST_SYSTEM]),
            'front_suspension_id' => $this->name('suspension', $row[self::FRONT_SUSPENSION]),
            'rear_suspension_id' => $this->name('suspension', $row[self::REAR_SUSPENSION]),
            'front_brakes_id' => $this->name('brake', $row[self::FRONT_BRAKES]),
            'rear_brakes_id' => $this->name('brake', $row[self::REAR_BRAKES]),
            'starter_id' => $this->name('starter', $row[self::STARTER]),
            'electrical_id' => $this->name('electrical', $row[self::ELECTRICAL]),
            'year' => $year,
            'slug' => $this->create_slug('bike', $make . ' ' . $model . ' ' . $year),
            'engine_displacement' => $this->float($row[self::ENGINE_DISPLACEMENT]),
            'power_ps' => $this->float($row[self::POWER_PS]),
            'power_rpm' => $this->int($row[self::POWER_RPM]),
            'torque_nm' => $this->float($row[self::TORQUE_NM]),
            'torque_rpm' => $this->int($row[self::TORQUE_RPM]),
            'valves_per_cylinder' => $this->int($row[self::VALVES_PER_CYLINDER]),
            'front_tire' => $row[self::FRONT_TIRE] ?: null,
            'rear_tire' => $row[self::REAR_TIRE] ?: null,
            'front_brakes_diameter' => $this->int($row[self::FRONT_BRAKES_DIAMETER]),
            'rear_brakes_diameter' => $this->int($row[self::REAR_BRAKES_DIAMETER]),
            'dry_weight' => $this->float($row[self::DRY_WEIGHT]),
            'full_weight' => $this->float($row[self::FULL_WEIGHT]),
            'seat_height' => $this->int($row[self::SEAT_HEIGHT]),
            'front_weight' => $this->float($row[self::FRONT_WEIGHT]),
            'rear_weight' => $this->float($row[self::REAR_WEIGHT]),
            'height' => $this->int($row[self::HEIGHT]),
            'length' => $this->int($row[self::LENGTH]),
            'width' => $this->int($row[self::WIDTH]),
            'ground_clearance' => $this->int($row[self::GROUND_CLEARANCE]),
            'wheelbase' => $this->int($row[self::WHEELBASE]),
            'fuel_capacity' => $this->float($row[self::FUEL_CAPACITY]),
            'reserve_fuel_capacity' => $this->float($row[self::RESERVE_FUEL_CAPACITY]),
            'oil_capacity' => $this->float($row[self::OIL_CAPACITY]),
        ]);
    }

    /**
     * @param string $table
     * @param string $slug
     * @return string
     * @throws DbalException
     * @throws Exception
     */
    private function create_slug(string $table, string $slug): string
    {
        $slug = strtolower($slug);
        $slug = preg_replace('/[^a-z0-9]+/', '-', $slug);
        $slug = preg_replace('/[-]+/', '-', $slug);

        $i = 1;
        $baseSlug = $slug;

        $query = $this->conn->prepare('SELECT 1 FROM ' . $table . ' WHERE slug = ?');
        $existing = $query->execute([$slug]);

        while ($existing->rowCount() > 0) {
            $slug = $baseSlug . '-' . ($i++);
            $existing = $query->execute([$slug]);
        }

        return $slug;
    }

    /**
     * @param string|int|float|null $value
     * @return float|null
     */
    private function float($value): ?float
    {
        return !empty($value) ? floatval($value) : null;
    }

    /**
     * @param string|int|null $value
     * @return int|null
     */
    private function int($value): ?int
    {
        return !empty($value) ? intval($value) : null;
    }

    /**
     * @param string $table
     * @param string|null $name
     * @return int
     * @throws DbalException
     */
    private function name(string $table, ?string $name): ?int
    {
        $name = substr($name ?? '', 0, 191);

        if ($name === null || empty($name)) {
            return null;
        }

        $key = strtolower($name);

        if (!isset($this->slugs[$table][$key])) {
            $existing = $this->conn->executeQuery('SELECT id, name_en FROM ' . $table . ' WHERE name_en  = ?', [$name]);

            if ($existing->rowCount() === 1) {
                $row = $existing->fetchAssociative();
                $this->slugs[$table][$key] = intval($row['id']);
            } else {
                $this->conn->insert($table, [
                    'name_en' => $name,
                ]);
                $this->slugs[$table][$key] = intval($this->conn->lastInsertId());
            }
        }

        return $this->slugs[$table][$key];
    }

    /**
     * @param string $name
     * @return int
     * @throws DbalException
     * @throws Exception
     */
    private function make(string $name): int
    {
        if (!isset($this->slugs['make'][$name])) {
            $existing = $this->conn->executeQuery(
                'SELECT * FROM make WHERE name = ?',
                [$name]
            );

            if ($existing->rowCount() > 0) {
                $row  = $existing->fetchAssociative();
                $this->slugs['make'][$name] = intval($row['id']);
            } else {
                $this->conn->insert('make', [
                    'name' => $name,
                    'slug' => $this->create_slug('make', $name),
                ]);
                $this->slugs['make'][$name] = intval($this->conn->lastInsertId());
            }
        }

        return $this->slugs['make'][$name];
    }

    /**
     * @param int $makeId
     * @param string $name
     * @return int
     * @throws DbalException
     */
    private function model(int $makeId, string $name): int
    {
        if (!isset($this->models[$makeId][$name])) {
            $existing = $this->conn->executeQuery(
                'SELECT * FROM model WHERE make_id = ? AND name = ?',
                [$makeId, $name]
            );

            if ($existing->rowCount() > 0) {
                $row  = $existing->fetchAssociative();
                $this->models[intval($row['make_id'])][$name] = intval($row['id']);
            } else {
                $this->conn->insert('model', [
                    'make_id' => $makeId,
                    'name' => $name,
                ]);
                $this->models[$makeId][$name] = intval($this->conn->lastInsertId());
            }
        }

        return $this->models[$makeId][$name];
    }

    /**
     * @param string|null $url
     * @return int|null
     * @throws DbalException
     */
    private function image(?string $url): ?int
    {
        if (empty($url)) {
            return null;
        }

        if (!isset($this->slugs['image'][$url])) {
            $existing = $this->conn->executeQuery('SELECT * FROM image WHERE url = ?', [$url]);

            if ($existing->rowCount() > 0) {
                $row = $existing->fetchAssociative();
                $this->slugs['image'][$url] = intval($row['id']);
            } else {
                $this->conn->insert('image', ['url' => $url]);
                $this->slugs['image'][$url] = intval($this->conn->lastInsertId());
            }
        }

        return $this->slugs['image'][$url];
    }
}
